==> open-xchange-dav_6.22.0.orig.tar.bz2: open-xchange-dav-6.22.0/com.openexchange.caldav/src/com/openexchange/caldav/mixins/SupportedCalendarComponentSet.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.caldav.mixins;

import com.openexchange.caldav.CaldavProtocol;
import com.openexchange.webdav.protocol.helpers.SingleXMLPropertyMixin;


/**
 * {@link SupportedCalendarComponentSet} 
 * 
 * Specifies the calendar component types (e.g., VEVENT, VTODO, etc.) that 
 * calendar object resources can contain in the calendar collection.
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 */
public class SupportedCalendarComponentSet extends SingleXMLPropertyMixin {
    
    public static final String VEVENT = "VEVENT";
    public static final String VTODO = "VTODO";
    
    private final String[] components;

    public SupportedCalendarComponentSet() {
        this(VEVENT);
    }

    public SupportedCalendarComponentSet(String...components) {
        super(CaldavProtocol.CAL_NS.getURI(), "supported-calendar-component-set");
        this.components = components;
    }

    @Override
    protected String getValue() {
        StringBuilder stringBuilder = new StringBuilder();
        if (null != this.components) {
            for (String component : components) {
                stringBuilder.append("<CAL:comp name=\"").append(component).append("\"/>");
            }
        }
        return stringBuilder.toString();
//        return "<CAL:comp name=\"VEVENT\"/><CAL:comp name=\"VTODO\"/>";
    }

}

==> open-xchange-dav_7.2.0.orig.tar.bz2: open-xchange-dav-7.2.0/com.openexchange.caldav/src/com/openexchange/caldav/mixins/SupportedCalendarComponentSet.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.caldav.mixins;

import com.openexchange.caldav.CaldavProtocol;
import com.openexchange.webdav.protocol.helpers.SingleXMLPropertyMixin;


/**
 * {@link SupportedCalendarComponentSet}
 *
 * Specifies the calendar component types (e.g., VEVENT, VTODO, etc.) that
 * calendar object resources can contain in the calendar collection.
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 */
public class SupportedCalendarComponentSet extends SingleXMLPropertyMixin {

    public static final String VEVENT = "VEVENT";
    public static final String VTODO = "VTODO";

    private final String[] components;

    public SupportedCalendarComponentSet() {
        this(VEVENT);
    }

    public SupportedCalendarComponentSet(String...components) {
        super(CaldavProtocol.CAL_NS.getURI(), "supported-calendar-component-set");
        this.components = components;
    }

    @Override
    protected String getValue() {
        com.openexchange.java.StringAllocator stringBuilder = new com.openexchange.java.StringAllocator();
        if (null != this.components) {
            for (String component : components) {
                stringBuilder.append("<CAL:comp name=\"").append(component).append("\"/>");
            }
        }
        return stringBuilder.toString();
//        return "<CAL:comp name=\"VEVENT\"/><CAL:comp name=\"VTODO\"/>";
    }

}
